@@ -56,6 +56,18 @@ Col<eT>::Col(const uword in_n_rows, const uword in_n_cols)
 
 
 
+template<typename eT>
+inline
+Col<eT>::Col(const SizeMat& s)
+  : Mat<eT>(arma_vec_indicator(), 0, 0, 1)
+  {
+  arma_extra_debug_sigprint();
+  
+  Mat<eT>::init_warm(s.n_rows, s.n_cols);
+  }
+
+
+
 template<typename eT>
 template<typename fill_type>
 inline
@@ -84,6 +96,21 @@ Col<eT>::Col(const uword in_n_rows, const uword in_n_cols, const fill::fill_clas
 
 
 
+template<typename eT>
+template<typename fill_type>
+inline
+Col<eT>::Col(const SizeMat& s, const fill::fill_class<fill_type>& f)
+  : Mat<eT>(arma_vec_indicator(), 0, 0, 1)
+  {
+  arma_extra_debug_sigprint();
+  
+  Mat<eT>::init_warm(s.n_rows, s.n_cols);
+  
+  (*this).fill(f);
+  }
+
+
+
 //! construct a column vector from specified text
 template<typename eT>
 inline
