@@ -37,6 +37,18 @@ real(const BaseCube<typename T1::pod_type, T1>& X)
 
 
 
+template<typename T1>
+arma_inline
+const T1&
+real(const SpBase<typename T1::pod_type,T1>& A)
+  {
+  arma_extra_debug_sigprint();
+  
+  return A.get_ref();
+  }
+
+
+
 template<typename T1>
 inline
 typename enable_if2< (is_arma_type<T1>::value && is_cx<typename T1::elem_type>::yes), const mtOp<typename T1::pod_type, T1, op_real> >::result
@@ -61,6 +73,18 @@ real(const BaseCube<std::complex<typename T1::pod_type>, T1>& X)
 
 
 
+template<typename T1>
+arma_inline
+const mtSpOp<typename T1::pod_type, T1, spop_real>
+real(const SpBase<std::complex<typename T1::pod_type>,T1>& A)
+  {
+  arma_extra_debug_sigprint();
+  
+  return mtSpOp<typename T1::pod_type, T1, spop_real>(A.get_ref());
+  }
+
+
+
 //
 // imag
 
@@ -92,6 +116,20 @@ imag(const BaseCube<typename T1::pod_type,T1>& X)
 
 
 
+template<typename T1>
+inline
+SpMat<typename T1::pod_type>
+imag(const SpBase<typename T1::pod_type,T1>& A)
+  {
+  arma_extra_debug_sigprint();
+  
+  const SpProxy<T1> P(A.get_ref());
+  
+  return SpMat<typename T1::pod_type>(P.get_n_rows(), P.get_n_cols());
+  }
+
+
+
 template<typename T1>
 inline
 typename enable_if2< (is_arma_type<T1>::value && is_cx<typename T1::elem_type>::yes), const mtOp<typename T1::pod_type, T1, op_imag> >::result
@@ -116,6 +154,18 @@ imag(const BaseCube<std::complex<typename T1::pod_type>,T1>& X)
 
 
 
+template<typename T1>
+arma_inline
+const mtSpOp<typename T1::pod_type, T1, spop_imag>
+imag(const SpBase<std::complex<typename T1::pod_type>,T1>& A)
+  {
+  arma_extra_debug_sigprint();
+  
+  return mtSpOp<typename T1::pod_type, T1, spop_imag>(A.get_ref());
+  }
+
+
+
 //
 // log
 
@@ -445,7 +495,7 @@ const T1&
 conj(const Base<typename T1::pod_type,T1>& A)
   {
   arma_extra_debug_sigprint();
-
+  
   return A.get_ref();
   }
 
@@ -457,7 +507,19 @@ const T1&
 conj(const BaseCube<typename T1::pod_type,T1>& A)
   {
   arma_extra_debug_sigprint();
+  
+  return A.get_ref();
+  }
 
+
+
+template<typename T1>
+arma_inline
+const T1&
+conj(const SpBase<typename T1::pod_type,T1>& A)
+  {
+  arma_extra_debug_sigprint();
+  
   return A.get_ref();
   }
 
@@ -469,7 +531,7 @@ const eOp<T1, eop_conj>
 conj(const Base<std::complex<typename T1::pod_type>,T1>& A)
   {
   arma_extra_debug_sigprint();
-
+  
   return eOp<T1, eop_conj>(A.get_ref());
   }
 
@@ -489,24 +551,12 @@ conj(const BaseCube<std::complex<typename T1::pod_type>,T1>& A)
 
 template<typename T1>
 arma_inline
-const typename Proxy<T1>::stored_type&
-conj(const eOp<T1, eop_conj>& A)
+const SpOp<T1, spop_conj>
+conj(const SpBase<std::complex<typename T1::pod_type>,T1>& A)
   {
   arma_extra_debug_sigprint();
   
-  return A.P.Q;
-  }
-
-
-
-template<typename T1>
-arma_inline
-const typename ProxyCube<T1>::stored_type&
-conj(const eOpCube<T1, eop_conj>& A)
-  {
-  arma_extra_debug_sigprint();
-  
-  return A.P.Q;
+  return SpOp<T1, spop_conj>(A.get_ref());
   }
 
 
