@@ -1,5 +1,5 @@
-// Copyright (C) 2008-2012 Conrad Sanderson
-// Copyright (C) 2008-2012 NICTA (www.nicta.com.au)
+// Copyright (C) 2008-2015 Conrad Sanderson
+// Copyright (C) 2008-2015 NICTA (www.nicta.com.au)
 // 
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -14,7 +14,7 @@ inline
 double
 randu()
   {
-  return double(eop_aux_randu<double>());
+  return arma_rng::randu<double>();
   }
 
 
@@ -23,7 +23,7 @@ inline
 typename arma_scalar_only<eT>::result
 randu()
   {
-  return eT(eop_aux_randu<eT>());
+  return eT(arma_rng::randu<eT>());
   }
 
 
@@ -73,6 +73,17 @@ randu(const uword n_rows, const uword n_cols)
 
 
 
+arma_inline
+const Gen<mat, gen_randu>
+randu(const SizeMat& s)
+  {
+  arma_extra_debug_sigprint();
+  
+  return Gen<mat, gen_randu>(s.n_rows, s.n_cols);
+  }
+
+
+
 template<typename obj_type>
 arma_inline
 const Gen<obj_type, gen_randu>
@@ -96,6 +107,19 @@ randu(const uword n_rows, const uword n_cols, const typename arma_Mat_Col_Row_on
 
 
 
+template<typename obj_type>
+arma_inline
+const Gen<obj_type, gen_randu>
+randu(const SizeMat& s, const typename arma_Mat_Col_Row_only<obj_type>::result* junk = 0)
+  {
+  arma_extra_debug_sigprint();
+  arma_ignore(junk);
+  
+  return randu<obj_type>(s.n_rows, s.n_cols);
+  }
+
+
+
 arma_inline
 const GenCube<cube::elem_type, gen_randu>
 randu(const uword n_rows, const uword n_cols, const uword n_slices)
@@ -107,6 +131,17 @@ randu(const uword n_rows, const uword n_cols, const uword n_slices)
 
 
 
+arma_inline
+const GenCube<cube::elem_type, gen_randu>
+randu(const SizeCube& s)
+  {
+  arma_extra_debug_sigprint();
+  
+  return GenCube<cube::elem_type, gen_randu>(s.n_rows, s.n_cols, s.n_slices);
+  }
+
+
+
 template<typename cube_type>
 arma_inline
 const GenCube<typename cube_type::elem_type, gen_randu>
@@ -120,4 +155,17 @@ randu(const uword n_rows, const uword n_cols, const uword n_slices, const typena
 
 
 
+template<typename cube_type>
+arma_inline
+const GenCube<typename cube_type::elem_type, gen_randu>
+randu(const SizeCube& s, const typename arma_Cube_only<cube_type>::result* junk = 0)
+  {
+  arma_extra_debug_sigprint();
+  arma_ignore(junk);
+  
+  return GenCube<typename cube_type::elem_type, gen_randu>(s.n_rows, s.n_cols, s.n_slices);
+  }
+
+
+
 //! @}
