@@ -1,5 +1,5 @@
-// Copyright (C) 2012 Conrad Sanderson
-// Copyright (C) 2012 NICTA (www.nicta.com.au)
+// Copyright (C) 2012-2015 Conrad Sanderson
+// Copyright (C) 2012-2015 NICTA (www.nicta.com.au)
 // Copyright (C) 2012 Arnold Wiliem
 // 
 // This Source Code Form is subject to the terms of the Mozilla Public
@@ -10,15 +10,15 @@
 
 template<typename T1>
 inline
-const Op<T1,op_unique>
-unique
-  (
-  const Base<typename T1::elem_type,T1>& A,
-  const typename arma_not_cx<typename T1::elem_type>::result* junk = 0
-  )
+typename
+enable_if2
+  <
+  is_arma_type<T1>::value,
+  const Op<T1,op_unique>
+  >::result
+unique(const T1& A)
   {
   arma_extra_debug_sigprint();
-  arma_ignore(junk);
   
-  return Op<T1,op_unique>( A.get_ref() );
+  return Op<T1,op_unique>(A);
   }
