@@ -60,4 +60,14 @@ class op_orth
 
 
 
+class op_null
+  {
+  public:
+  
+  template<typename T1>
+  inline static void apply(Mat<typename T1::elem_type>& out, const Op<T1, op_null>& expr);
+  };
+
+
+
 //! @}
