@@ -1,5 +1,5 @@
-// Copyright (C) 2010-2013 Conrad Sanderson
-// Copyright (C) 2010-2013 NICTA (www.nicta.com.au)
+// Copyright (C) 2010-2015 Conrad Sanderson
+// Copyright (C) 2010-2015 NICTA (www.nicta.com.au)
 // 
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -74,11 +74,11 @@ subview_elem1<eT,T1>::inplace_op(const eT val)
     
     arma_debug_check( ( (ii >= m_n_elem) || (jj >= m_n_elem) ), "Mat::elem(): index out of bounds" );
     
-         if(is_same_type<op_type, op_subview_elem_equ          >::yes) { m_mem[ii] =  val; m_mem[jj] =  val; }
-    else if(is_same_type<op_type, op_subview_elem_inplace_plus >::yes) { m_mem[ii] += val; m_mem[jj] += val; }
-    else if(is_same_type<op_type, op_subview_elem_inplace_minus>::yes) { m_mem[ii] -= val; m_mem[jj] -= val; }
-    else if(is_same_type<op_type, op_subview_elem_inplace_schur>::yes) { m_mem[ii] *= val; m_mem[jj] *= val; }
-    else if(is_same_type<op_type, op_subview_elem_inplace_div  >::yes) { m_mem[ii] /= val; m_mem[jj] /= val; }
+    if(is_same_type<op_type, op_internal_equ  >::yes) { m_mem[ii] =  val; m_mem[jj] =  val; }
+    if(is_same_type<op_type, op_internal_plus >::yes) { m_mem[ii] += val; m_mem[jj] += val; }
+    if(is_same_type<op_type, op_internal_minus>::yes) { m_mem[ii] -= val; m_mem[jj] -= val; }
+    if(is_same_type<op_type, op_internal_schur>::yes) { m_mem[ii] *= val; m_mem[jj] *= val; }
+    if(is_same_type<op_type, op_internal_div  >::yes) { m_mem[ii] /= val; m_mem[jj] /= val; }
     }
   
   if(iq < aa_n_elem)
@@ -87,11 +87,11 @@ subview_elem1<eT,T1>::inplace_op(const eT val)
     
     arma_debug_check( (ii >= m_n_elem) , "Mat::elem(): index out of bounds" ); 
     
-         if(is_same_type<op_type, op_subview_elem_equ          >::yes) { m_mem[ii] =  val; }
-    else if(is_same_type<op_type, op_subview_elem_inplace_plus >::yes) { m_mem[ii] += val; }
-    else if(is_same_type<op_type, op_subview_elem_inplace_minus>::yes) { m_mem[ii] -= val; }
-    else if(is_same_type<op_type, op_subview_elem_inplace_schur>::yes) { m_mem[ii] *= val; }
-    else if(is_same_type<op_type, op_subview_elem_inplace_div  >::yes) { m_mem[ii] /= val; }
+    if(is_same_type<op_type, op_internal_equ  >::yes) { m_mem[ii] =  val; }
+    if(is_same_type<op_type, op_internal_plus >::yes) { m_mem[ii] += val; }
+    if(is_same_type<op_type, op_internal_minus>::yes) { m_mem[ii] -= val; }
+    if(is_same_type<op_type, op_internal_schur>::yes) { m_mem[ii] *= val; }
+    if(is_same_type<op_type, op_internal_div  >::yes) { m_mem[ii] /= val; }
     }
   }
 
@@ -113,11 +113,11 @@ subview_elem1<eT,T1>::inplace_op(const subview_elem1<eT,T2>& x)
     
     const Mat<eT> tmp(x);
     
-         if(is_same_type<op_type, op_subview_elem_equ          >::yes) { s.operator= (tmp); }
-    else if(is_same_type<op_type, op_subview_elem_inplace_plus >::yes) { s.operator+=(tmp); }
-    else if(is_same_type<op_type, op_subview_elem_inplace_minus>::yes) { s.operator-=(tmp); }
-    else if(is_same_type<op_type, op_subview_elem_inplace_schur>::yes) { s.operator%=(tmp); }
-    else if(is_same_type<op_type, op_subview_elem_inplace_div  >::yes) { s.operator/=(tmp); }
+    if(is_same_type<op_type, op_internal_equ  >::yes) { s.operator= (tmp); }
+    if(is_same_type<op_type, op_internal_plus >::yes) { s.operator+=(tmp); }
+    if(is_same_type<op_type, op_internal_minus>::yes) { s.operator-=(tmp); }
+    if(is_same_type<op_type, op_internal_schur>::yes) { s.operator%=(tmp); }
+    if(is_same_type<op_type, op_internal_div  >::yes) { s.operator/=(tmp); }
     }
   else
     {
@@ -165,11 +165,11 @@ subview_elem1<eT,T1>::inplace_op(const subview_elem1<eT,T2>& x)
         "Mat::elem(): index out of bounds"
         );
       
-           if(is_same_type<op_type, op_subview_elem_equ          >::yes) { s_m_mem[s_ii]  = x_m_mem[x_ii]; s_m_mem[s_jj]  = x_m_mem[x_jj]; }
-      else if(is_same_type<op_type, op_subview_elem_inplace_plus >::yes) { s_m_mem[s_ii] += x_m_mem[x_ii]; s_m_mem[s_jj] += x_m_mem[x_jj]; }
-      else if(is_same_type<op_type, op_subview_elem_inplace_minus>::yes) { s_m_mem[s_ii] -= x_m_mem[x_ii]; s_m_mem[s_jj] -= x_m_mem[x_jj]; }
-      else if(is_same_type<op_type, op_subview_elem_inplace_schur>::yes) { s_m_mem[s_ii] *= x_m_mem[x_ii]; s_m_mem[s_jj] *= x_m_mem[x_jj]; }
-      else if(is_same_type<op_type, op_subview_elem_inplace_div  >::yes) { s_m_mem[s_ii] /= x_m_mem[x_ii]; s_m_mem[s_jj] /= x_m_mem[x_jj]; }
+      if(is_same_type<op_type, op_internal_equ  >::yes) { s_m_mem[s_ii]  = x_m_mem[x_ii]; s_m_mem[s_jj]  = x_m_mem[x_jj]; }
+      if(is_same_type<op_type, op_internal_plus >::yes) { s_m_mem[s_ii] += x_m_mem[x_ii]; s_m_mem[s_jj] += x_m_mem[x_jj]; }
+      if(is_same_type<op_type, op_internal_minus>::yes) { s_m_mem[s_ii] -= x_m_mem[x_ii]; s_m_mem[s_jj] -= x_m_mem[x_jj]; }
+      if(is_same_type<op_type, op_internal_schur>::yes) { s_m_mem[s_ii] *= x_m_mem[x_ii]; s_m_mem[s_jj] *= x_m_mem[x_jj]; }
+      if(is_same_type<op_type, op_internal_div  >::yes) { s_m_mem[s_ii] /= x_m_mem[x_ii]; s_m_mem[s_jj] /= x_m_mem[x_jj]; }
       }
     
     if(iq < s_aa_n_elem)
@@ -183,11 +183,11 @@ subview_elem1<eT,T1>::inplace_op(const subview_elem1<eT,T2>& x)
         "Mat::elem(): index out of bounds"
         );
       
-           if(is_same_type<op_type, op_subview_elem_equ          >::yes) { s_m_mem[s_ii]  = x_m_mem[x_ii]; }
-      else if(is_same_type<op_type, op_subview_elem_inplace_plus >::yes) { s_m_mem[s_ii] += x_m_mem[x_ii]; }
-      else if(is_same_type<op_type, op_subview_elem_inplace_minus>::yes) { s_m_mem[s_ii] -= x_m_mem[x_ii]; }
-      else if(is_same_type<op_type, op_subview_elem_inplace_schur>::yes) { s_m_mem[s_ii] *= x_m_mem[x_ii]; }
-      else if(is_same_type<op_type, op_subview_elem_inplace_div  >::yes) { s_m_mem[s_ii] /= x_m_mem[x_ii]; }
+      if(is_same_type<op_type, op_internal_equ  >::yes) { s_m_mem[s_ii]  = x_m_mem[x_ii]; }
+      if(is_same_type<op_type, op_internal_plus >::yes) { s_m_mem[s_ii] += x_m_mem[x_ii]; }
+      if(is_same_type<op_type, op_internal_minus>::yes) { s_m_mem[s_ii] -= x_m_mem[x_ii]; }
+      if(is_same_type<op_type, op_internal_schur>::yes) { s_m_mem[s_ii] *= x_m_mem[x_ii]; }
+      if(is_same_type<op_type, op_internal_div  >::yes) { s_m_mem[s_ii] /= x_m_mem[x_ii]; }
       }
     }
   }
@@ -237,11 +237,11 @@ subview_elem1<eT,T1>::inplace_op(const Base<eT,T2>& x)
       
       arma_debug_check( ( (ii >= m_n_elem) || (jj >= m_n_elem) ), "Mat::elem(): index out of bounds" );
       
-           if(is_same_type<op_type, op_subview_elem_equ          >::yes) { m_mem[ii] =  X[iq]; m_mem[jj]  = X[jq]; }
-      else if(is_same_type<op_type, op_subview_elem_inplace_plus >::yes) { m_mem[ii] += X[iq]; m_mem[jj] += X[jq]; }
-      else if(is_same_type<op_type, op_subview_elem_inplace_minus>::yes) { m_mem[ii] -= X[iq]; m_mem[jj] -= X[jq]; }
-      else if(is_same_type<op_type, op_subview_elem_inplace_schur>::yes) { m_mem[ii] *= X[iq]; m_mem[jj] *= X[jq]; }
-      else if(is_same_type<op_type, op_subview_elem_inplace_div  >::yes) { m_mem[ii] /= X[iq]; m_mem[jj] /= X[jq]; }
+      if(is_same_type<op_type, op_internal_equ  >::yes) { m_mem[ii] =  X[iq]; m_mem[jj]  = X[jq]; }
+      if(is_same_type<op_type, op_internal_plus >::yes) { m_mem[ii] += X[iq]; m_mem[jj] += X[jq]; }
+      if(is_same_type<op_type, op_internal_minus>::yes) { m_mem[ii] -= X[iq]; m_mem[jj] -= X[jq]; }
+      if(is_same_type<op_type, op_internal_schur>::yes) { m_mem[ii] *= X[iq]; m_mem[jj] *= X[jq]; }
+      if(is_same_type<op_type, op_internal_div  >::yes) { m_mem[ii] /= X[iq]; m_mem[jj] /= X[jq]; }
       }
     
     if(iq < aa_n_elem)
@@ -250,11 +250,11 @@ subview_elem1<eT,T1>::inplace_op(const Base<eT,T2>& x)
       
       arma_debug_check( (ii >= m_n_elem) , "Mat::elem(): index out of bounds" );
       
-           if(is_same_type<op_type, op_subview_elem_equ          >::yes) { m_mem[ii] =  X[iq]; }
-      else if(is_same_type<op_type, op_subview_elem_inplace_plus >::yes) { m_mem[ii] += X[iq]; }
-      else if(is_same_type<op_type, op_subview_elem_inplace_minus>::yes) { m_mem[ii] -= X[iq]; }
-      else if(is_same_type<op_type, op_subview_elem_inplace_schur>::yes) { m_mem[ii] *= X[iq]; }
-      else if(is_same_type<op_type, op_subview_elem_inplace_div  >::yes) { m_mem[ii] /= X[iq]; }
+      if(is_same_type<op_type, op_internal_equ  >::yes) { m_mem[ii] =  X[iq]; }
+      if(is_same_type<op_type, op_internal_plus >::yes) { m_mem[ii] += X[iq]; }
+      if(is_same_type<op_type, op_internal_minus>::yes) { m_mem[ii] -= X[iq]; }
+      if(is_same_type<op_type, op_internal_schur>::yes) { m_mem[ii] *= X[iq]; }
+      if(is_same_type<op_type, op_internal_div  >::yes) { m_mem[ii] /= X[iq]; }
       }
     }
   else
@@ -274,11 +274,11 @@ subview_elem1<eT,T1>::inplace_op(const Base<eT,T2>& x)
       
       arma_debug_check( ( (ii >= m_n_elem) || (jj >= m_n_elem) ), "Mat::elem(): index out of bounds" );
       
-           if(is_same_type<op_type, op_subview_elem_equ          >::yes) { m_mem[ii] =  X[iq]; m_mem[jj]  = X[jq]; }
-      else if(is_same_type<op_type, op_subview_elem_inplace_plus >::yes) { m_mem[ii] += X[iq]; m_mem[jj] += X[jq]; }
-      else if(is_same_type<op_type, op_subview_elem_inplace_minus>::yes) { m_mem[ii] -= X[iq]; m_mem[jj] -= X[jq]; }
-      else if(is_same_type<op_type, op_subview_elem_inplace_schur>::yes) { m_mem[ii] *= X[iq]; m_mem[jj] *= X[jq]; }
-      else if(is_same_type<op_type, op_subview_elem_inplace_div  >::yes) { m_mem[ii] /= X[iq]; m_mem[jj] /= X[jq]; }
+      if(is_same_type<op_type, op_internal_equ  >::yes) { m_mem[ii] =  X[iq]; m_mem[jj]  = X[jq]; }
+      if(is_same_type<op_type, op_internal_plus >::yes) { m_mem[ii] += X[iq]; m_mem[jj] += X[jq]; }
+      if(is_same_type<op_type, op_internal_minus>::yes) { m_mem[ii] -= X[iq]; m_mem[jj] -= X[jq]; }
+      if(is_same_type<op_type, op_internal_schur>::yes) { m_mem[ii] *= X[iq]; m_mem[jj] *= X[jq]; }
+      if(is_same_type<op_type, op_internal_div  >::yes) { m_mem[ii] /= X[iq]; m_mem[jj] /= X[jq]; }
       }
     
     if(iq < aa_n_elem)
@@ -287,11 +287,11 @@ subview_elem1<eT,T1>::inplace_op(const Base<eT,T2>& x)
       
       arma_debug_check( (ii >= m_n_elem) , "Mat::elem(): index out of bounds" );
       
-           if(is_same_type<op_type, op_subview_elem_equ          >::yes) { m_mem[ii] =  X[iq]; }
-      else if(is_same_type<op_type, op_subview_elem_inplace_plus >::yes) { m_mem[ii] += X[iq]; }
-      else if(is_same_type<op_type, op_subview_elem_inplace_minus>::yes) { m_mem[ii] -= X[iq]; }
-      else if(is_same_type<op_type, op_subview_elem_inplace_schur>::yes) { m_mem[ii] *= X[iq]; }
-      else if(is_same_type<op_type, op_subview_elem_inplace_div  >::yes) { m_mem[ii] /= X[iq]; }
+      if(is_same_type<op_type, op_internal_equ  >::yes) { m_mem[ii] =  X[iq]; }
+      if(is_same_type<op_type, op_internal_plus >::yes) { m_mem[ii] += X[iq]; }
+      if(is_same_type<op_type, op_internal_minus>::yes) { m_mem[ii] -= X[iq]; }
+      if(is_same_type<op_type, op_internal_schur>::yes) { m_mem[ii] *= X[iq]; }
+      if(is_same_type<op_type, op_internal_div  >::yes) { m_mem[ii] /= X[iq]; }
       }
     }
   }
@@ -340,7 +340,7 @@ subview_elem1<eT,T1>::fill(const eT val)
   {
   arma_extra_debug_sigprint();
   
-  inplace_op<op_subview_elem_equ>(val);
+  inplace_op<op_internal_equ>(val);
   }
 
 
@@ -352,7 +352,7 @@ subview_elem1<eT,T1>::zeros()
   {
   arma_extra_debug_sigprint();
   
-  inplace_op<op_subview_elem_equ>(eT(0));
+  inplace_op<op_internal_equ>(eT(0));
   }
 
 
@@ -364,7 +364,7 @@ subview_elem1<eT,T1>::ones()
   {
   arma_extra_debug_sigprint();
   
-  inplace_op<op_subview_elem_equ>(eT(1));
+  inplace_op<op_internal_equ>(eT(1));
   }
 
 
@@ -474,7 +474,7 @@ subview_elem1<eT,T1>::operator+= (const eT val)
   {
   arma_extra_debug_sigprint();
   
-  inplace_op<op_subview_elem_inplace_plus>(val);
+  inplace_op<op_internal_plus>(val);
   }
 
 
@@ -486,7 +486,7 @@ subview_elem1<eT,T1>::operator-= (const eT val)
   {
   arma_extra_debug_sigprint();
   
-  inplace_op<op_subview_elem_inplace_minus>(val);
+  inplace_op<op_internal_minus>(val);
   }
 
 
@@ -498,7 +498,7 @@ subview_elem1<eT,T1>::operator*= (const eT val)
   {
   arma_extra_debug_sigprint();
   
-  inplace_op<op_subview_elem_inplace_schur>(val);
+  inplace_op<op_internal_schur>(val);
   }
 
 
@@ -510,7 +510,7 @@ subview_elem1<eT,T1>::operator/= (const eT val)
   {
   arma_extra_debug_sigprint();
   
-  inplace_op<op_subview_elem_inplace_div>(val);
+  inplace_op<op_internal_div>(val);
   }
 
 
@@ -528,7 +528,7 @@ subview_elem1<eT,T1>::operator_equ(const subview_elem1<eT,T2>& x)
   {
   arma_extra_debug_sigprint();
   
-  inplace_op<op_subview_elem_equ>(x);
+  inplace_op<op_internal_equ>(x);
   }
 
 
@@ -568,7 +568,7 @@ subview_elem1<eT,T1>::operator+= (const subview_elem1<eT,T2>& x)
   {
   arma_extra_debug_sigprint();
   
-  inplace_op<op_subview_elem_inplace_plus>(x);
+  inplace_op<op_internal_plus>(x);
   }
 
 
@@ -581,7 +581,7 @@ subview_elem1<eT,T1>::operator-= (const subview_elem1<eT,T2>& x)
   {
   arma_extra_debug_sigprint();
   
-  inplace_op<op_subview_elem_inplace_minus>(x);
+  inplace_op<op_internal_minus>(x);
   }
 
 
@@ -594,7 +594,7 @@ subview_elem1<eT,T1>::operator%= (const subview_elem1<eT,T2>& x)
   {
   arma_extra_debug_sigprint();
   
-  inplace_op<op_subview_elem_inplace_schur>(x);
+  inplace_op<op_internal_schur>(x);
   }
 
 
@@ -607,7 +607,7 @@ subview_elem1<eT,T1>::operator/= (const subview_elem1<eT,T2>& x)
   {
   arma_extra_debug_sigprint();
   
-  inplace_op<op_subview_elem_inplace_div>(x);
+  inplace_op<op_internal_div>(x);
   }
 
 
@@ -620,7 +620,7 @@ subview_elem1<eT,T1>::operator= (const Base<eT,T2>& x)
   {
   arma_extra_debug_sigprint();
   
-  inplace_op<op_subview_elem_equ>(x);
+  inplace_op<op_internal_equ>(x);
   }
 
 
@@ -633,7 +633,7 @@ subview_elem1<eT,T1>::operator+= (const Base<eT,T2>& x)
   {
   arma_extra_debug_sigprint();
   
-  inplace_op<op_subview_elem_inplace_plus>(x);
+  inplace_op<op_internal_plus>(x);
   }
 
 
@@ -646,7 +646,7 @@ subview_elem1<eT,T1>::operator-= (const Base<eT,T2>& x)
   {
   arma_extra_debug_sigprint();
   
-  inplace_op<op_subview_elem_inplace_minus>(x);
+  inplace_op<op_internal_minus>(x);
   }
 
 
@@ -659,7 +659,7 @@ subview_elem1<eT,T1>::operator%= (const Base<eT,T2>& x)
   {
   arma_extra_debug_sigprint();
   
-  inplace_op<op_subview_elem_inplace_schur>(x);
+  inplace_op<op_internal_schur>(x);
   }
 
 
@@ -672,7 +672,7 @@ subview_elem1<eT,T1>::operator/= (const Base<eT,T2>& x)
   {
   arma_extra_debug_sigprint();
   
-  inplace_op<op_subview_elem_inplace_div>(x);
+  inplace_op<op_internal_div>(x);
   }
 
 
@@ -785,10 +785,10 @@ subview_elem1<eT,T1>::mat_inplace_op(Mat<eT>& out, const subview_elem1& in)
     
     arma_debug_check( ( (ii >= m_n_elem) || (jj >= m_n_elem) ), "Mat::elem(): index out of bounds" );
     
-         if(is_same_type<op_type, op_subview_elem_inplace_plus >::yes) { out_mem[i] += m_mem[ii]; out_mem[j] += m_mem[jj]; }
-    else if(is_same_type<op_type, op_subview_elem_inplace_minus>::yes) { out_mem[i] -= m_mem[ii]; out_mem[j] -= m_mem[jj]; }
-    else if(is_same_type<op_type, op_subview_elem_inplace_schur>::yes) { out_mem[i] *= m_mem[ii]; out_mem[j] *= m_mem[jj]; }
-    else if(is_same_type<op_type, op_subview_elem_inplace_div  >::yes) { out_mem[i] /= m_mem[ii]; out_mem[j] /= m_mem[jj]; }
+    if(is_same_type<op_type, op_internal_plus >::yes) { out_mem[i] += m_mem[ii]; out_mem[j] += m_mem[jj]; }
+    if(is_same_type<op_type, op_internal_minus>::yes) { out_mem[i] -= m_mem[ii]; out_mem[j] -= m_mem[jj]; }
+    if(is_same_type<op_type, op_internal_schur>::yes) { out_mem[i] *= m_mem[ii]; out_mem[j] *= m_mem[jj]; }
+    if(is_same_type<op_type, op_internal_div  >::yes) { out_mem[i] /= m_mem[ii]; out_mem[j] /= m_mem[jj]; }
     }
   
   if(i < aa_n_elem)
@@ -797,10 +797,10 @@ subview_elem1<eT,T1>::mat_inplace_op(Mat<eT>& out, const subview_elem1& in)
     
     arma_debug_check( (ii >= m_n_elem) , "Mat::elem(): index out of bounds" );
     
-         if(is_same_type<op_type, op_subview_elem_inplace_plus >::yes) { out_mem[i] += m_mem[ii]; }
-    else if(is_same_type<op_type, op_subview_elem_inplace_minus>::yes) { out_mem[i] -= m_mem[ii]; }
-    else if(is_same_type<op_type, op_subview_elem_inplace_schur>::yes) { out_mem[i] *= m_mem[ii]; }
-    else if(is_same_type<op_type, op_subview_elem_inplace_div  >::yes) { out_mem[i] /= m_mem[ii]; }
+    if(is_same_type<op_type, op_internal_plus >::yes) { out_mem[i] += m_mem[ii]; }
+    if(is_same_type<op_type, op_internal_minus>::yes) { out_mem[i] -= m_mem[ii]; }
+    if(is_same_type<op_type, op_internal_schur>::yes) { out_mem[i] *= m_mem[ii]; }
+    if(is_same_type<op_type, op_internal_div  >::yes) { out_mem[i] /= m_mem[ii]; }
     }
   }
 
@@ -813,7 +813,7 @@ subview_elem1<eT,T1>::plus_inplace(Mat<eT>& out, const subview_elem1& in)
   {
   arma_extra_debug_sigprint();
   
-  mat_inplace_op<op_subview_elem_inplace_plus>(out, in);
+  mat_inplace_op<op_internal_plus>(out, in);
   }
 
 
@@ -825,7 +825,7 @@ subview_elem1<eT,T1>::minus_inplace(Mat<eT>& out, const subview_elem1& in)
   {
   arma_extra_debug_sigprint();
   
-  mat_inplace_op<op_subview_elem_inplace_minus>(out, in);
+  mat_inplace_op<op_internal_minus>(out, in);
   }
 
 
@@ -837,7 +837,7 @@ subview_elem1<eT,T1>::schur_inplace(Mat<eT>& out, const subview_elem1& in)
   {
   arma_extra_debug_sigprint();
   
-  mat_inplace_op<op_subview_elem_inplace_schur>(out, in);
+  mat_inplace_op<op_internal_schur>(out, in);
   }
 
 
@@ -849,7 +849,7 @@ subview_elem1<eT,T1>::div_inplace(Mat<eT>& out, const subview_elem1& in)
   {
   arma_extra_debug_sigprint();
   
-  mat_inplace_op<op_subview_elem_inplace_div>(out, in);
+  mat_inplace_op<op_internal_div>(out, in);
   }
 
 
